Avoid some checkpatch warnings.
---
 drivers/md/dm-thin.c                              |   16 +++++++--------
 drivers/md/persistent-data/dm-block-manager.c     |   11 ++++++----
 drivers/md/persistent-data/dm-btree-internal.h    |    4 ++-
 drivers/md/persistent-data/dm-bufio.c             |   23 +++++++++-------------
 drivers/md/persistent-data/dm-space-map-checker.c |    4 ---
 drivers/md/persistent-data/dm-space-map-common.c  |    2 -
 6 files changed, 30 insertions(+), 30 deletions(-)

Index: linux-3.1-rc9/drivers/md/dm-thin.c
===================================================================
--- linux-3.1-rc9.orig/drivers/md/dm-thin.c
+++ linux-3.1-rc9/drivers/md/dm-thin.c
@@ -1080,10 +1080,10 @@ static void provision_block(struct thin_
 	}
 
 	if (bio_data_dir(bio) == READ) {
-	        zero_fill_bio(bio);
-	        cell_release_singleton(cell, bio);
-	        bio_endio(bio, 0);
-	        return;
+		zero_fill_bio(bio);
+		cell_release_singleton(cell, bio);
+		bio_endio(bio, 0);
+		return;
 	}
 
 	r = alloc_data_block(tc, &data_block);
@@ -1602,12 +1602,12 @@ static int parse_pool_features(struct dm
 
 /*
  * thin-pool <metadata dev> <data dev>
- *           <data block size (sectors)>
- *           <low water mark (sectors)>
- *           [<#feature args> [<arg>]*]
+ *	     <data block size (sectors)>
+ *	     <low water mark (sectors)>
+ *	     [<#feature args> [<arg>]*]
  *
  * Optional feature arguments are:
- *           skip_block_zeroing: skips the zeroing of newly-provisioned blocks.
+ *	     skip_block_zeroing: skips the zeroing of newly-provisioned blocks.
  */
 static int pool_ctr(struct dm_target *ti, unsigned argc, char **argv)
 {
Index: linux-3.1-rc9/drivers/md/persistent-data/dm-block-manager.c
===================================================================
--- linux-3.1-rc9.orig/drivers/md/persistent-data/dm-block-manager.c
+++ linux-3.1-rc9/drivers/md/persistent-data/dm-block-manager.c
@@ -156,7 +156,7 @@ static void __wake_many(struct block_loc
 	struct waiter *w, *tmp;
 
 	BUG_ON(lock->count < 0);
-	list_for_each_entry_safe (w, tmp, &lock->waiters, list) {
+	list_for_each_entry_safe(w, tmp, &lock->waiters, list) {
 		if (lock->count >= MAX_HOLDERS)
 			return;
 
@@ -280,7 +280,10 @@ static int bl_down_write(struct block_lo
 	w.task = current;
 	w.wants_write = 1;
 
-	/* writers given priority, we know there's only one mutator in the system, so ignoring the ordering reversal */
+	/*
+	 * Writers given priority. We know there's only one mutator in the
+	 * system, so ignoring the ordering reversal.
+	 */
 	list_add(&w.list, &lock->waiters);
 	spin_unlock(&lock->lock);
 
@@ -340,7 +343,7 @@ static void dm_block_manager_write_callb
 	if (aux->validator) {
 		aux->validator->prepare_for_write(aux->validator, buf,
 			 dm_bufio_get_block_size(dm_bufio_get_client(buf)));
- 	}
+	}
 }
 
 /*----------------------------------------------------------------
@@ -395,7 +398,7 @@ static int dm_bm_validate_buffer(struct 
 				(unsigned long long)
 					dm_bufio_get_block_number(buf));
 			return -EINVAL;
- 		}
+		}
 	}
 
 	return 0;
Index: linux-3.1-rc9/drivers/md/persistent-data/dm-btree-internal.h
===================================================================
--- linux-3.1-rc9.orig/drivers/md/persistent-data/dm-btree-internal.h
+++ linux-3.1-rc9/drivers/md/persistent-data/dm-btree-internal.h
@@ -108,7 +108,9 @@ static inline void *value_base(struct no
 	return &n->keys[le32_to_cpu(n->header.max_entries)];
 }
 
-/* FIXME: now that value size is stored in the node we don't need the third param */
+/*
+ * FIXME: Now that value size is stored in node we don't need the third parm.
+ */
 static inline void *value_ptr(struct node *n, uint32_t index, size_t value_size)
 {
 	BUG_ON(value_size != le32_to_cpu(n->header.value_size));
Index: linux-3.1-rc9/drivers/md/persistent-data/dm-bufio.c
===================================================================
--- linux-3.1-rc9.orig/drivers/md/persistent-data/dm-bufio.c
+++ linux-3.1-rc9/drivers/md/persistent-data/dm-bufio.c
@@ -154,26 +154,26 @@ static inline int dm_bufio_cache_index(s
 /*----------------------------------------------------------------*/
 
 /* Default cache size --- available memory divided by the ratio */
-static unsigned long dm_bufio_default_cache_size = 0;
+static unsigned long dm_bufio_default_cache_size;
 
 /* Total cache size set by the user */
-static unsigned long dm_bufio_cache_size = 0;
+static unsigned long dm_bufio_cache_size;
 
 /*
  * A copy of dm_bufio_cache_size because dm_bufio_cache_size can change
  * anytime.  If it disagrees, the user has changed cache size
  */
-static unsigned long dm_bufio_cache_size_latch = 0;
+static unsigned long dm_bufio_cache_size_latch;
 
 static DEFINE_SPINLOCK(param_spinlock);
 
 /* Buffers are freed after this timeout */
 static unsigned dm_bufio_max_age = DM_BUFIO_DEFAULT_AGE;
-static unsigned long dm_bufio_peak_allocated = 0;
-static unsigned long dm_bufio_allocated_kmem_cache = 0;
-static unsigned long dm_bufio_allocated_get_free_pages = 0;
-static unsigned long dm_bufio_allocated_vmalloc = 0;
-static unsigned long dm_bufio_current_allocated = 0;
+static unsigned long dm_bufio_peak_allocated;
+static unsigned long dm_bufio_allocated_kmem_cache;
+static unsigned long dm_bufio_allocated_get_free_pages;
+static unsigned long dm_bufio_allocated_vmalloc;
+static unsigned long dm_bufio_current_allocated;
 
 /*----------------------------------------------------------------*/
 
@@ -1440,11 +1440,8 @@ static void __exit dm_bufio_exit(void)
 			kmem_cache_destroy(kc);
 	}
 
-	for (i = 0; i < ARRAY_SIZE(dm_bufio_cache_names); i++) {
-		char *nm = dm_bufio_cache_names[i];
-		if (nm)
-			kfree(nm);
-	}
+	for (i = 0; i < ARRAY_SIZE(dm_bufio_cache_names); i++)
+		kfree(dm_bufio_cache_names[i]);
 
 	if (dm_bufio_client_count != 0) {
 		printk(KERN_CRIT "%s: dm_bufio_client_count leaked: %d",
Index: linux-3.1-rc9/drivers/md/persistent-data/dm-space-map-checker.c
===================================================================
--- linux-3.1-rc9.orig/drivers/md/persistent-data/dm-space-map-checker.c
+++ linux-3.1-rc9/drivers/md/persistent-data/dm-space-map-checker.c
@@ -193,11 +193,9 @@ static int sm_checker_get_nr_free(struct
 			    smc->counts.counts[b] == 0)
 				n++;
 
-		if (n != *count) {
+		if (n != *count)
 			DMERR("free block counts differ, checker %u, sm-disk:%u",
 			      (unsigned) n, (unsigned) *count);
-			// BUG();
-		}
 	}
 	return r;
 }
Index: linux-3.1-rc9/drivers/md/persistent-data/dm-space-map-common.c
===================================================================
--- linux-3.1-rc9.orig/drivers/md/persistent-data/dm-space-map-common.c
+++ linux-3.1-rc9/drivers/md/persistent-data/dm-space-map-common.c
@@ -338,7 +338,7 @@ int sm_ll_find_free_block(struct ll_disk
 		bit_end = (i == index_end - 1) ?  end : ll->entries_per_block;
 
 		r = sm_find_free(dm_bitmap_data(blk),
-				 max((unsigned) begin, (unsigned) le32_to_cpu(ie_disk.none_free_before)),
+				 max_t(unsigned, begin, le32_to_cpu(ie_disk.none_free_before)),
 				 bit_end, &position);
 		if (r == -ENOSPC) {
 			/*
